#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-
# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
# Copyright (C) 2021  Jeronimo Wiederhold <jeronimo.wiederhold@sva.de>
#                     for SVA System Vertrieb Alexander GmbH

# Example output
"""
<name>|<state>|<status>
<<<hpe_oneview_enclosures:sep(124)>>>
Frame1-oben-CZJ7170S95|Configured|OK
Frame2-mitte-CZJ71706K5|Configured|OK
Frame3-unten-CZ3715W1XP|Configured|OK
"""

from .agent_based_api.v1 import *

info_list = ["name", "state", "status"]
state_map = {
    0: State.OK,
    1: State.WARN,
    2: State.CRIT,
    3: State.UNKNOWN
}

def parse_hpe_oneview_enclosures(string_table):
    output = []
    for enclosure in string_table:
        info_map = dict(zip(info_list, enclosure))
        output.append(info_map)
    return output

register.agent_section(
    name="hpe_oneview_enclosures",
    parse_function=parse_hpe_oneview_enclosures
)

def discovery_hpe_oneview_enclosures(section):
    for enclosure in section:
        yield Service(item=enclosure["name"])


def check_hpe_oneview_enclosures(item, params, section):
    map_status = params["map_status"]
    map_state = params["map_state"]

    for enclosure in section:
        if enclosure["name"] == item:

            s= state_map[map_status[enclosure["status"]]]
            
            yield Result(state=s, summary="Status: {}".format(enclosure["status"]))

            s= state_map[map_state[enclosure["state"]]]

            yield Result(state=s, summary="State: {}".format(enclosure["state"]))


register.check_plugin(
    name="hpe_oneview_enclosures",
    service_name="Enclosure %s",
    check_ruleset_name="hpe_oneview_enclosures",
    check_default_parameters={
        "map_status": {
            "OK": 0,
            "Disabled": 1,
            "Warning": 1,
            "Critical": 2,
            "Unknown": 3
            },
        "map_state": {
            "Adding": 0,
            "Configured": 0,
            "Configuring": 0,
            "Interrupted": 2,
            "Monitored": 1,
            "Pending": 0,
            "RemoveFailed": 2,
            "Removing": 1,
            "Unmanaged": 1,
            "Unsupported": 2,
            }
        },
    discovery_function=discovery_hpe_oneview_enclosures,
    check_function=check_hpe_oneview_enclosures,
)