#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-
# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
# Copyright (C) 2021  Jeronimo Wiederhold <jeronimo.wiederhold@sva.de>
#                     for SVA System Vertrieb Alexander GmbH

# Example output
"""
<name>|<status>|<state>
<<<hpe_oneview_fc_networks:sep(124)>>>
FC-Fabric-D|OK|Active
FC-Fabric-C|OK|Active
FC-Fabric-A|OK|Active
FC-Fabric-B|OK|Active
"""

from .agent_based_api.v1 import *

info_list = ["name", "status", "state"]
state_map = {
    0: State.OK,
    1: State.WARN,
    2: State.CRIT,
    3: State.UNKNOWN
}

def parse_hpe_oneview_fc_networks(string_table):
    output = []
    for network in string_table:
        info_map = dict(zip(info_list, network))
        output.append(info_map)
    return output

register.agent_section(
    name="hpe_oneview_fc_networks",
    parse_function=parse_hpe_oneview_fc_networks
)

def discovery_hpe_oneview_fc_networks(section):
    for network in section:
        yield Service(item=network["name"])


def check_hpe_oneview_fc_networks(item, params, section):
    map_status = params["map_status"]

    for network in section:
        if network["name"] == item:

            s= state_map[map_status[network["status"]]]
            
            yield Result(state=s, summary="Status: {}, State: {}".format(network["status"], network["state"]))


register.check_plugin(
    name="hpe_oneview_fc_networks",
    service_name="FC Network %s",
    check_ruleset_name="hpe_oneview_fc_networks",
    check_default_parameters={
        "map_status": {
            "OK": 0,
            "Disabled": 1,
            "Warning": 1,
            "Critical": 2,
            "Unknown": 3
            },
        },
    discovery_function=discovery_hpe_oneview_fc_networks,
    check_function=check_hpe_oneview_fc_networks,
)