#!/usr/bin/env python3
# -*- encoding: utf-8; py-indent-offset: 4 -*-
# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
# Copyright (C) 2021  Jeronimo Wiederhold <jeronimo.wiederhold@sva.de>
#                     for SVA System Vertrieb Alexander GmbH

# Example output
"""
<name>|<state>|<status>|<powerState>|<interconnectHardwareHealth>
<<<hpe_oneview_interconnects:sep(124)>>>
Frame2-mitte-CZJ71706K5, interconnect 6|Configured|Critical|On|Ok
Frame1-oben-CZJ7170S95, interconnect 6|Configured|OK|On|Ok
Frame3-unten-CZ3715W1XP, interconnect 6|Configured|OK|On|Ok
Frame1-oben-CZJ7170S95, interconnect 3|Configured|OK|On|Ok
Frame3-unten-CZ3715W1XP, interconnect 3|Configured|Critical|On|Ok
"""

from .agent_based_api.v1 import *

info_list = ["name", "state", "status", "powerState", "interconnectHardwareHealth"]
state_map = {
    0: State.OK,
    1: State.WARN,
    2: State.CRIT,
    3: State.UNKNOWN
}

def parse_hpe_oneview_interconnects(string_table):
    output = []
    for interconnect in string_table:
        info_map = dict(zip(info_list, interconnect))
        output.append(info_map)
    return output

register.agent_section(
    name="hpe_oneview_interconnects",
    parse_function=parse_hpe_oneview_interconnects
)

def discovery_hpe_oneview_interconnects(section):
    for interconnect in section:
        yield Service(item=interconnect["name"])


def check_hpe_oneview_interconnects(item, params, section):
    map_status = params["map_status"]
    map_powerState = params["map_powerState"]

    for interconnect in section:
        if interconnect["name"] == item:

            s= state_map[map_status[interconnect["status"]]]
            
            yield Result(state=s, summary="Status: {}".format(interconnect["status"]))

            s= state_map[map_powerState[interconnect["powerState"]]]

            yield Result(state=s, summary="PowerState: {}, State: {}".format(interconnect["powerState"], interconnect["state"]))


register.check_plugin(
    name="hpe_oneview_interconnects",
    service_name="Interconnect %s",
    check_ruleset_name="hpe_oneview_interconnects",
    check_default_parameters={
        "map_status": {
            "OK": 0,
            "Disabled": 1,
            "Warning": 1,
            "Critical": 2,
            "Unknown": 3
            },
        "map_powerState": {
            "On": 0,
            "Off": 1,
            "NA": 2,
            "Unknown": 3
            }
        },
    discovery_function=discovery_hpe_oneview_interconnects,
    check_function=check_hpe_oneview_interconnects,
)