#!/usr/bin/python
# -*- encoding: utf-8; py-indent-offset: 4 -*-
# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
# Copyright (C) 2021  Jeronimo Wiederhold <jeronimo.wiederhold@sva.de>
#                     for SVA System Vertrieb Alexander GmbH

from cmk.gui.i18n import _
from cmk.gui.plugins.wato.datasource_programs import RulespecGroupDatasourcePrograms
from cmk.gui.plugins.wato import (
    RulespecGroup,
    monitoring_macro_help,
    rulespec_group_registry,
    rulespec_registry,
    HostRulespec,
)
from cmk.gui.valuespec import Dictionary, Password, TextAscii, Integer

def _valuespec_hpe_oneview():
    return Dictionary(
        elements = [
            ( "domain",
              TextAscii(
                  title = _("Domain (defaults to local)"),
                  allow_empty = True,
              )
            ),
            ( "username",
              TextAscii(
                  title = _("Username"),
                  allow_empty = False,
              )
            ),
            ( "password",
              Password(
                  title = _("Password"),
                  allow_empty = False,
              )
            ),
            ( "api",
              Integer(
                  title = _("API Version"),
                  default_value = 1200
              )
            ),
        ],
        optional_keys = ["domain"],
        title = _("HPE OneView Agent"),
        help = _("This rule selects the HPE OneView Special Agent instead of the normal Check_MK Agent "
             "which collects the data through API"),
#        match = 'first'
        )

rulespec_registry.register((HostRulespec(
    group=RulespecGroupDatasourcePrograms,
    name="special_agents:hpe_oneview",
    valuespec=_valuespec_hpe_oneview,
)))
