#!/usr/bin/python
# -*- encoding: utf-8; py-indent-offset: 4 -*-
# +------------------------------------------------------------+
# |                                                            |
# |             | |             | |            | |             |
# |          ___| |__   ___  ___| | ___ __ ___ | | __          |
# |         / __| '_ \ / _ \/ __| |/ / '_ ` _ \| |/ /          |
# |        | (__| | | |  __/ (__|   <| | | | | |   <           |
# |         \___|_| |_|\___|\___|_|\_\_| |_| |_|_|\_\          |
# |                                   custom code by SVA       |
# |                                                            |
# +------------------------------------------------------------+
#
# Copyright (C) 2020  Jeronimo Wiederhold <jeronimo.wiederhold@sva.de>
#                     for SVA System Vertrieb Alexander GmbH

from cmk.gui.i18n import _
from cmk.gui.valuespec import (
    Dictionary,
    Integer,
    Tuple,
    MonitoringState
)

from cmk.gui.plugins.wato import (
    CheckParameterRulespecWithoutItem,
    rulespec_registry,
    RulespecGroupCheckParametersApplications,
)


def _parameter_valuespec_hpe_oneview_server_hardware():
    return Dictionary(elements=[
        ("map_status",
         Dictionary(
             title=_("Map Attribute 'Status'"),
             elements=[
                 ("OK", MonitoringState(title=_("OK"), default_value=0)),
                 ("Disabled", MonitoringState(title=_("Disabled"), default_value=1)),
                 ("Warning", MonitoringState(title=_("Warning"), default_value=1)),
                 ("Critical", MonitoringState(title=_("Critical"), default_value=2)),
                 ("Unknown", MonitoringState(title=_("Unknown"), default_value=3)),
             ],
             optional_keys=False,
         )),
        ("map_state",
         Dictionary(
             title=_("Map Attribute 'state'"),
             elements=[
                 ("Monitored", MonitoringState(title=_("Monitored"), default_value=0)),
                 ("NoProfileApplied", MonitoringState(title=_("NoProfileApplied"), default_value=0)),
                 ("Adding", MonitoringState(title=_("Adding"), default_value=0)),
                 ("Unknown", MonitoringState(title=_("Unknown"), default_value=3)),
                 ("Unmanaged", MonitoringState(title=_("Unmanaged"), default_value=1)),
                 ("Removing", MonitoringState(title=_("Removing"), default_value=1)),
                 ("RemoveFailed", MonitoringState(title=_("RemoveFailed"), default_value=2)),
                 ("Removed", MonitoringState(title=_("Removed"), default_value=1)),
                 ("ApplyingProfile", MonitoringState(title=_("ApplyingProfile"), default_value=0)),
                 ("ProfileApplied", MonitoringState(title=_("ProfileApplied"), default_value=0)),
                 ("RemovingProfile", MonitoringState(title=_("RemovingProfile"), default_value=1)),
                 ("ProfileError", MonitoringState(title=_("ProfileError"), default_value=2)),
                 ("Unsupported", MonitoringState(title=_("Unsupported"), default_value=2)),
                 ("UpdatingFirmware", MonitoringState(title=_("UpdatingFirmware"), default_value=0)),

             ],
             optional_keys=False,
         )),
    ],)

rulespec_registry.register(
    CheckParameterRulespecWithoutItem(
        check_group_name="hpe_oneview_server_hardware",
        group=RulespecGroupCheckParametersApplications,
        match_type="dict",
        parameter_valuespec=_parameter_valuespec_hpe_oneview_server_hardware,
        title=lambda: _("HPE OneView Server Hardware States"),
    ))
